Affected by GO-2024-2688
and 10 other vulnerabilities
GO-2024-2688 : KubeVirt NULL pointer dereference flaw in kubevirt.io/kubevirt
GO-2024-2756 : Privilege Escalation in kubevirt in kubevirt.io/kubevirt
GO-2024-2765 : Permissions bypass in KubeVirt in kubevirt.io/kubevirt
GO-2024-2816 : kubevirt allows a local attacker to execute arbitrary code via a crafted command in kubevirt.io/kubevirt
GO-2025-4102 : KubeVirt Isolation Detection Flaw Allows Arbitrary File Permission Changes in kubevirt.io/kubevirt
GO-2025-4103 : KubeVirt Affected by an Authentication Bypass in Kubernetes Aggregation Layer in kubevirt.io/kubevirt
GO-2025-4105 : KubeVirt VMI Denial-of-Service (DoS) Using Pod Impersonation in kubevirt.io/kubevirt
GO-2025-4107 : KubeVirt Improper TLS Certificate Management Handling Allows API Identity Spoofing in kubevirt.io/kubevirt
GO-2025-4109 : KubeVirt Arbitrary Container File Read in kubevirt.io/kubevirt
GO-2025-4110 : KubeVirt Vulnerable to Arbitrary Host File Read and Write in kubevirt.io/kubevirt
GO-2026-4384 : KubeVirt Guest Agent DoS via Excessive Network Interface Reports in kubevirt.io/kubevirt
Discover Packages
kubevirt.io/kubevirt
pkg
version
package
Version:
v0.10.0
Opens a new window with list of versions in this module.
Published: Nov 8, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
* This file is part of the KubeVirt project
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
* Copyright 2018 Red Hat, Inc.
*
type Info struct {
GitVersion string `json:"gitVersion"`
GitCommit string `json:"gitCommit"`
GitTreeState string `json:"gitTreeState"`
BuildDate string `json:"buildDate"`
GoVersion string `json:"goVersion"`
Compiler string `json:"compiler"`
Platform string `json:"platform"`
}
String returns info as a human-friendly version string.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.