Documentation
¶
Index ¶
- Constants
- func ConstructProxyKey(id string, port int) string
- func GetMigrationPortsList(isBlockMigration bool) (ports []int)
- func NewSourceProxy(unixSocketPath string, tcpTargetAddress string, serverTLSConfig *tls.Config, ...) *migrationProxy
- func NewTargetProxy(tcpBindAddress string, tcpBindPort int, serverTLSConfig *tls.Config, ...) *migrationProxy
- func SourceUnixFile(baseDir string, key string) string
- type MigrationProxyListener
- type ProxyManager
Constants ¶
const ( LibvirtDirectMigrationPort = 49152 LibvirtBlockMigrationPort = 49153 )
Variables ¶
This section is empty.
Functions ¶
func ConstructProxyKey ¶ added in v0.15.0
func GetMigrationPortsList ¶ added in v0.15.0
func NewSourceProxy ¶
func NewSourceProxy(unixSocketPath string, tcpTargetAddress string, serverTLSConfig *tls.Config, clientTLSConfig *tls.Config, vmiUID string) *migrationProxy
Source proxy exposes a unix socket server and pipes to an outbound TCP connection.
func NewTargetProxy ¶
func NewTargetProxy(tcpBindAddress string, tcpBindPort int, serverTLSConfig *tls.Config, clientTLSConfig *tls.Config, virtqemudSocketPath string, vmiUID string) *migrationProxy
Target proxy listens on a tcp socket and pipes to a virtqemud unix socket
func SourceUnixFile ¶
Types ¶
type MigrationProxyListener ¶ added in v0.41.0
type MigrationProxyListener interface {
Start() error
Stop()
}
type ProxyManager ¶
type ProxyManager interface {
StartTargetListener(key string, targetUnixFiles []string) error
GetTargetListenerPorts(key string) map[string]int
StopTargetListener(key string)
StartSourceListener(key string, targetAddress string, destSrcPortMap map[string]int, baseDir string) error
GetSourceListenerFiles(key string) []string
StopSourceListener(key string)
OpenListenerCount() int
InitiateGracefulShutdown()
}
func NewMigrationProxyManager ¶
func NewMigrationProxyManager(serverTLSConfig *tls.Config, clientTLSConfig *tls.Config, config *virtconfig.ClusterConfig) ProxyManager
Click to show internal directories.
Click to hide internal directories.