Affected by GO-2024-2688
and 10 other vulnerabilities
GO-2024-2688: KubeVirt NULL pointer dereference flaw in kubevirt.io/kubevirt
GO-2024-2756: Privilege Escalation in kubevirt in kubevirt.io/kubevirt
GO-2024-2765: Permissions bypass in KubeVirt in kubevirt.io/kubevirt
GO-2024-2816: kubevirt allows a local attacker to execute arbitrary code via a crafted command in kubevirt.io/kubevirt
GO-2025-4102: KubeVirt Isolation Detection Flaw Allows Arbitrary File Permission Changes in kubevirt.io/kubevirt
GO-2025-4103: KubeVirt Affected by an Authentication Bypass in Kubernetes Aggregation Layer in kubevirt.io/kubevirt
GO-2025-4105: KubeVirt VMI Denial-of-Service (DoS) Using Pod Impersonation in kubevirt.io/kubevirt
GO-2025-4107: KubeVirt Improper TLS Certificate Management Handling Allows API Identity Spoofing in kubevirt.io/kubevirt
GO-2025-4109: KubeVirt Arbitrary Container File Read in kubevirt.io/kubevirt
GO-2025-4110: KubeVirt Vulnerable to Arbitrary Host File Read and Write in kubevirt.io/kubevirt
GO-2026-4384: KubeVirt Guest Agent DoS via Excessive Network Interface Reports in kubevirt.io/kubevirt
package
Version:
v0.19.0
Opens a new window with list of versions in this module.
Published: Jul 4, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 3
Opens a new window with list of known importers.
Documentation
¶
generate a new "expose" command
func (*Command) RunE ¶
executing the "expose" command
Source Files
¶
Click to show internal directories.
Click to hide internal directories.